==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-mount/mount_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>Button</name>
    <message>
        <location filename="../../../button.cpp" line="38"/>
        <source>Removable media/devices manager</source>
        <translation type="unfinished">Gestor de medios y dispositivos extraíbles</translation>
    </message>
</context>
<context>
    <name>Configuration</name>
    <message>
        <location filename="../../../configuration.ui" line="14"/>
        <source>Removable Media Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../configuration.ui" line="20"/>
        <source>Behaviour</source>
        <translation type="unfinished">Comportamiento</translation>
    </message>
    <message>
        <location filename="../../../configuration.ui" line="26"/>
        <source>When a device is connected :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../configuration.cpp" line="40"/>
        <source>Popup menu</source>
        <translation type="unfinished">Menú contextual</translation>
    </message>
    <message>
        <location filename="../../../configuration.cpp" line="41"/>
        <source>Show info</source>
        <translation type="unfinished">Mostrar información</translation>
    </message>
    <message>
        <location filename="../../../configuration.cpp" line="42"/>
        <source>Do nothing</source>
        <translation type="unfinished">No hacer nada</translation>
    </message>
</context>
<context>
    <name>DeviceActionInfo</name>
    <message>
        <location filename="../../../actions/deviceaction_info.cpp" line="40"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation type="unfinished">Se conectó el dispositivo &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../../../actions/deviceaction_info.cpp" line="45"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation type="unfinished">Se expulsó el dispositivo &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../../../actions/deviceaction_info.cpp" line="50"/>
        <source>Removable media/devices manager</source>
        <translation type="unfinished">Gestor de medios y dispositivos extraíbles</translation>
    </message>
</context>
<context>
    <name>LXQtMountConfiguration</name>
    <message>
        <source>LXQt Removable media manager settings</source>
        <translation type="vanished">Configuración del gestor de medios extraíbles de LXQt</translation>
    </message>
    <message>
        <source>Behaviour</source>
        <translation type="vanished">Comportamiento</translation>
    </message>
    <message>
        <source>When a device is connected </source>
        <translation type="vanished">Cuando un dispositivo se conecte</translation>
    </message>
    <message>
        <source>Popup menu</source>
        <translation type="vanished">Menú contextual</translation>
    </message>
    <message>
        <source>Show info</source>
        <translation type="vanished">Mostrar información</translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation type="vanished">No hacer nada</translation>
    </message>
</context>
<context>
    <name>MenuDiskItem</name>
    <message>
        <source>Click to access this device from other applications.</source>
        <translation type="vanished">Haga clic para acceder a este dispositivo desde otras aplicaciones.</translation>
    </message>
    <message>
        <source>Click to eject this disc.</source>
        <translation type="vanished">Haga clic para expulsar este disco.</translation>
    </message>
    <message>
        <location filename="../../../menudiskitem.cpp" line="155"/>
        <source>Mounting of &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; failed: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../menudiskitem.cpp" line="157"/>
        <location filename="../../../menudiskitem.cpp" line="178"/>
        <source>Removable media/devices manager</source>
        <translation type="unfinished">Gestor de medios y dispositivos extraíbles</translation>
    </message>
    <message>
        <location filename="../../../menudiskitem.cpp" line="176"/>
        <source>Unmounting of &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; failed: %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MountButton</name>
    <message>
        <source>Removable media/devices manager</source>
        <translation type="vanished">Gestor de medios y dispositivos extraíbles</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation type="vanished">Se conectó el dispositivo &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation type="vanished">Se expulsó el dispositivo &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>No devices Available.</source>
        <translation type="vanished">No hay dispositivos disponibles.</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <location filename="../../../popup.cpp" line="68"/>
        <source>No devices are available</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-panel/plugin-mount/mount_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>Button</name>
    <message>
        <location filename="../../../button.cpp" line="38"/>
        <source>Removable media/devices manager</source>
        <translation>Gestor de medios y dispositivos extraíbles</translation>
    </message>
</context>
<context>
    <name>Configuration</name>
    <message>
        <location filename="../../../configuration.ui" line="14"/>
        <source>Removable Media Settings</source>
        <translation>Configuración de medios extraíbles</translation>
    </message>
    <message>
        <location filename="../../../configuration.ui" line="20"/>
        <source>Behaviour</source>
        <translation>Comportamiento</translation>
    </message>
    <message>
        <location filename="../../../configuration.ui" line="26"/>
        <source>When a device is connected :</source>
        <translation>Al conectar un dispositivo:</translation>
    </message>
    <message>
        <location filename="../../../configuration.cpp" line="40"/>
        <source>Popup menu</source>
        <translation>Menú contextual</translation>
    </message>
    <message>
        <location filename="../../../configuration.cpp" line="41"/>
        <source>Show info</source>
        <translation>Mostrar información</translation>
    </message>
    <message>
        <location filename="../../../configuration.cpp" line="42"/>
        <source>Do nothing</source>
        <translation>No hacer nada</translation>
    </message>
</context>
<context>
    <name>DeviceActionInfo</name>
    <message>
        <location filename="../../../actions/deviceaction_info.cpp" line="40"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>Se ha conectado el dispositivo &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../../../actions/deviceaction_info.cpp" line="45"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>Se ha expulsado el dispositivo &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../../../actions/deviceaction_info.cpp" line="50"/>
        <source>Removable media/devices manager</source>
        <translation>Gestor de medios y dispositivos extraíbles</translation>
    </message>
</context>
<context>
    <name>LXQtMountConfiguration</name>
    <message>
        <source>LXQt Removable media manager settings</source>
        <translation type="vanished">Configuración del gestor de medios extraíbles de LXQt</translation>
    </message>
    <message>
        <source>Behaviour</source>
        <translation type="vanished">Comportamiento</translation>
    </message>
    <message>
        <source>When a device is connected </source>
        <translation type="vanished">Cuando un dispositivo se conecte</translation>
    </message>
    <message>
        <source>Popup menu</source>
        <translation type="vanished">Menú contextual</translation>
    </message>
    <message>
        <source>Show info</source>
        <translation type="vanished">Mostrar información</translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation type="vanished">No hacer nada</translation>
    </message>
</context>
<context>
    <name>MenuDiskItem</name>
    <message>
        <source>Click to access this device from other applications.</source>
        <translation type="vanished">Haga clic para acceder a este dispositivo desde otras aplicaciones.</translation>
    </message>
    <message>
        <source>Click to eject this disc.</source>
        <translation type="vanished">Haga clic para expulsar este disco.</translation>
    </message>
    <message>
        <location filename="../../../menudiskitem.cpp" line="155"/>
        <source>Mounting of &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; failed: %2</source>
        <translation>El montaje de &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; ha fallado: %2</translation>
    </message>
    <message>
        <location filename="../../../menudiskitem.cpp" line="157"/>
        <location filename="../../../menudiskitem.cpp" line="178"/>
        <source>Removable media/devices manager</source>
        <translation>Gestor de medios y dispositivos extraíbles</translation>
    </message>
    <message>
        <location filename="../../../menudiskitem.cpp" line="176"/>
        <source>Unmounting of &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; failed: %2</source>
        <translation>El desmontaje de &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; ha fallado: %2</translation>
    </message>
</context>
<context>
    <name>MountButton</name>
    <message>
        <source>Removable media/devices manager</source>
        <translation type="vanished">Gestor de medios y dispositivos extraíbles</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation type="vanished">Se conectó el dispositivo &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation type="vanished">Se expulsó el dispositivo &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>No devices Available.</source>
        <translation type="vanished">No hay dispositivos disponibles.</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <location filename="../../../popup.cpp" line="68"/>
        <source>No devices are available</source>
        <translation>No hay dispositivos disponibles</translation>
    </message>
</context>
</TS>
